%bcond_with bootstrap

%if %{with bootstrap}
%global mbi 1
%endif

Name:           xmvn
Version:        4.2.0
Release:        %mkrel 5
Group:          Development/Java
Summary:        Local Extensions for Apache Maven
License:        Apache-2.0
URL:            https://fedora-java.github.io/xmvn/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/fedora-java/xmvn/releases/download/%{version}/xmvn-%{version}.tar.xz

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(com.beust:jcommander)
BuildRequires:  mvn(javax.inject:javax.inject)
BuildRequires:  mvn(org.apache.commons:commons-compress)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-api)
BuildRequires:  mvn(org.apache.maven.resolver:maven-resolver-util)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-model-builder)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.easymock:easymock)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.inject)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:  mvn(org.ow2.asm:asm)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-simple)
BuildRequires:  mvn(org.xmlunit:xmlunit-assertj3)
# Maven home is used as template for XMvn home
BuildRequires:  maven
%endif

Requires:       %{name}-minimal = %{version}-%{release}
Requires:       maven >= 3.6.1

%description
This package provides extensions for Apache Maven that can be used to
manage system artifact repository and use it to resolve Maven
artifacts in offline mode, as well as Maven plugins to help with
creating RPM packages containing Maven artifacts.

%package        minimal
Summary:        Dependency-reduced version of XMvn
Requires:       %{name}-core = %{version}-%{release}
Requires:       apache-commons-cli
Requires:       apache-commons-lang3
Requires:       atinject
Requires:       google-guice
Requires:       guava
Requires:       maven-resolver
Requires:       maven-wagon
Requires:       plexus-cipher
Requires:       plexus-classworlds
Requires:       plexus-containers-component-annotations
Requires:       plexus-interpolation
Requires:       plexus-sec-dispatcher
Requires:       plexus-utils
Requires:       sisu
Requires:       slf4j

Requires:       maven-lib >= 3.4.0
Requires:       maven-jdk-binding
Suggests:       maven-openjdk21

%description    minimal
This package provides minimal version of XMvn, incapable of using
remote repositories.

%package        core
Summary:        XMvn library

%description    core
This package provides XMvn API and XMvn Core modules, which implement
the essential functionality of XMvn such as resolution of artifacts
from system repository.

%package        mojo
Summary:        XMvn MOJO

%description    mojo
This package provides XMvn MOJO, which is a Maven plugin that consists
of several MOJOs.  Some goals of these MOJOs are intended to be
attached to default Maven lifecycle when building packages, others can
be called directly from Maven command line.

%package        tools
Summary:        XMvn tools
# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description    tools
This package provides various XMvn tools:
* XMvn Install, which is a command-line interface to XMvn installer.
  The installer reads reactor metadata and performs artifact
  installation according to specified configuration.
* XMvn Resolver, which is a very simple commald-line tool to resolve
  Maven artifacts from system repositories.  Basically it's just an
  interface to artifact resolution mechanism implemented by XMvn Core.
  The primary intended use case of XMvn Resolver is debugging local
  artifact repositories.
* XMvn Subst, which is a tool that can substitute Maven artifact files
  with symbolic links to corresponding files in artifact repository.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package provides %{summary}.

%prep
%setup -q

%mvn_package ::tar.gz: __noinstall
%mvn_package ":{xmvn,xmvn-connector}" xmvn
%mvn_package ":xmvn-{api,core,parent}" core
%mvn_package ":xmvn-mojo" mojo
%mvn_package ":xmvn-{install,resolve,subst,tools}" tools

# Don't put Class-Path attributes in manifests
%pom_remove_plugin :maven-jar-plugin xmvn-tools

# Copy Maven home packaged as RPM instead of unpacking Maven binary
# tarball with maven-dependency-plugin
%pom_remove_plugin :maven-dependency-plugin
maven_home=$(realpath $(dirname $(realpath $(%{?jpb_env} which mvn)))/..)
mver=$(sed -n '/<mavenVersion>/{s/.*>\(.*\)<.*/\1/;p}' \
           xmvn-parent/pom.xml)
mkdir -p target/dependency/
cp -a "${maven_home}" target/dependency/apache-maven-$mver

# Workaround easymock incompatibility with Java 17 that should be fixed
# in easymock 4.4: https://github.com/easymock/easymock/issues/274
%pom_add_plugin :maven-surefire-plugin xmvn-connector "<configuration>
    <argLine>--add-opens=java.base/java.lang=ALL-UNNAMED</argLine></configuration>"
%pom_add_plugin :maven-surefire-plugin xmvn-tools/xmvn-install "<configuration>
    <argLine>--add-opens=java.base/java.lang=ALL-UNNAMED</argLine></configuration>"

%build
%mvn_build -j -- -P\\!quality

version=4.*
tar --delay-directory-restore -xvf target/xmvn-*-bin.tar.gz
chmod -R +rwX %{name}-${version}
# These are installed as doc
rm -f %{name}-${version}/{AUTHORS-XMVN,README-XMVN.md,LICENSE,NOTICE,NOTICE-XMVN}
# Not needed - we use JPackage launcher scripts
rm -Rf %{name}-${version}/lib/{installer,resolver,subst}/
# Irrelevant Maven launcher scripts
rm -f %{name}-${version}/bin/*


%install
%mvn_install

version=4.*
maven_home=$(realpath $(dirname $(realpath $(%{?jpb_env} which mvn)))/..)

install -d -m 755 %{buildroot}%{_datadir}/%{name}
cp -r%{?mbi:L} %{name}-${version}/* %{buildroot}%{_datadir}/%{name}/

for cmd in mvn mvnDebug; do
    cat <<EOF >%{buildroot}%{_datadir}/%{name}/bin/$cmd
#!/bin/sh -e
export _FEDORA_MAVEN_HOME="%{_datadir}/%{name}"
exec %{_datadir}/maven/bin/$cmd "\${@}"
EOF
    chmod 755 %{buildroot}%{_datadir}/%{name}/bin/$cmd
done

# helper scripts
%jpackage_script org.fedoraproject.xmvn.tools.install.cli.InstallerCli "" "" xmvn/xmvn-install:xmvn/xmvn-api:xmvn/xmvn-core:beust-jcommander:slf4j/api:slf4j/simple:objectweb-asm/asm:commons-compress xmvn-install
%jpackage_script org.fedoraproject.xmvn.tools.resolve.ResolverCli "" "" xmvn/xmvn-resolve:xmvn/xmvn-api:xmvn/xmvn-core:beust-jcommander xmvn-resolve
%jpackage_script org.fedoraproject.xmvn.tools.subst.SubstCli "" "" xmvn/xmvn-subst:xmvn/xmvn-api:xmvn/xmvn-core:beust-jcommander xmvn-subst

# copy over maven boot and lib directories
cp -r%{?mbi:L} ${maven_home}/boot/* %{buildroot}%{_datadir}/%{name}/boot/
cp -r%{?mbi:L} ${maven_home}/lib/* %{buildroot}%{_datadir}/%{name}/lib/

# possibly recreate symlinks that can be automated with xmvn-subst
%if !0%{?mbi}
%{name}-subst -s -R %{buildroot} %{buildroot}%{_datadir}/%{name}/
%endif

# /usr/bin/xmvn
ln -s %{_datadir}/%{name}/bin/mvn %{buildroot}%{_bindir}/%{name}

# mvn-local symlink
ln -s %{name} %{buildroot}%{_bindir}/mvn-local

# make sure our conf is identical to maven so yum won't freak out
install -d -m 755 %{buildroot}%{_datadir}/%{name}/conf/
cp -P ${maven_home}/conf/settings.xml %{buildroot}%{_datadir}/%{name}/conf/
cp -P ${maven_home}/bin/m2.conf %{buildroot}%{_datadir}/%{name}/bin/

# Make sure javapackages config is not bundled
rm -rf %{buildroot}%{_datadir}/%{name}/{configuration.xml,config.d/,conf/toolchains.xml,maven-metadata/}

# WARNING
# Mageia specifix: !!!DO NOT DROP THIS SYMLINK!!!
mv %buildroot%{_datadir}/%{name}/conf/logging %buildroot%{_datadir}/%{name}/conf/logging.orig
ln -s /etc/maven/logging/ %buildroot%{_datadir}/%{name}/conf/logging

# Workaround for rpm bug 447156 - rpm fails to change directory to symlink
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Directory_Replacement/
%pretrans -p <lua> minimal
path = "/usr/share/xmvn/conf/logging"
st = posix.stat(path)
if st and st.type == "directory" then
  status = os.rename(path, path .. ".rpmmoved")
  if not status then
    suffix = 0
    while not status do
      suffix = suffix + 1
      status = os.rename(path .. ".rpmmoved", path .. ".rpmmoved." .. suffix)
    end
    os.rename(path, path .. ".rpmmoved")
  end
end

%files
%{_bindir}/mvn-local

%files minimal -f .mfiles-xmvn
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/bin
%dir %{_datadir}/%{name}/lib
%{_datadir}/%{name}/lib/*.jar
%{_datadir}/%{name}/lib/ext
%{_datadir}/%{name}/lib/jansi-native
%{_datadir}/%{name}/bin/m2.conf
%{_datadir}/%{name}/bin/mvn
%{_datadir}/%{name}/bin/mvnDebug
%{_datadir}/%{name}/boot
%{_datadir}/%{name}/conf
%ghost %{_datadir}/%{name}/conf/logging.rpmmoved

%files core -f .mfiles-core
%license LICENSE NOTICE
%doc AUTHORS README.md

%files mojo -f .mfiles-mojo

%files tools -f .mfiles-tools
%{_bindir}/%{name}-install
%{_bindir}/%{name}-resolve
%{_bindir}/%{name}-subst

%files javadoc
%license LICENSE NOTICE


%changelog
* Fri May 17 2024 ns80 <ns80> 4.2.0-5.mga10
+ Revision: 2064591
- build without bootstrap

* Fri May 17 2024 ns80 <ns80> 4.2.0-4.mga10
+ Revision: 2064576
- bootstrap build
- rebuild for maven 3.9.6 and java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 4.2.0-3.mga10
+ Revision: 1986520
- non-bootstrap build

* Thu Sep 14 2023 daviddavid <daviddavid> 4.2.0-2.mga10
+ Revision: 1986516
- add back symlink /etc/maven/logging/ to /usr/share/xmvn/conf/logging

* Thu Sep 14 2023 daviddavid <daviddavid> 4.2.0-1.mga10
+ Revision: 1986495
- Update to upstream version 4.2.0

* Sat Jul 30 2022 neoclust <neoclust> 4.0.0-14.mga9
+ Revision: 1873339
- Add conflict to ease upgrade

* Mon Jul 25 2022 neoclust <neoclust> 4.0.0-13.mga9
+ Revision: 1871511
- Rebuild without bootstrap and add a workaround for a working xmvn

* Mon Jul 25 2022 neoclust <neoclust> 4.0.0-12.mga9
+ Revision: 1871496
- Enable bootstrap to unbreak xmvn
- Rebuild against maven

* Mon Jul 25 2022 neoclust <neoclust> 4.0.0-11.mga9
+ Revision: 1871476
- Rebuild w/o bootstrap

* Mon Jul 25 2022 neoclust <neoclust> 4.0.0-10.mga9
+ Revision: 1870979
- Fix bootstrap
- New version 4.0.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Sep 03 2020 daviddavid <daviddavid> 3.1.0-5.mga8
+ Revision: 1621279
- Honour source parameter in javadoc mojo
+ neoclust <neoclust>
- Rebuild against new jar files
- Rebuild against new deps

* Wed Aug 19 2020 neoclust <neoclust> 3.1.0-4.mga8
+ Revision: 1616346
- Rebuild against new maven
- Remove workaround

* Wed Aug 19 2020 neoclust <neoclust> 3.1.0-2.mga8
+ Revision: 1616334
- Rebuild against new maven rpms

* Sun Aug 09 2020 neoclust <neoclust> 3.1.0-1.mga8
+ Revision: 1612242
- New version 3.1.0

* Sun Feb 16 2020 umeabot <umeabot> 3.0.0-8.mga8
+ Revision: 1536219
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 3.0.0-7.mga8
+ Revision: 1453725
- Port to maven-invoker 3.0.1
- Port to xmlunit2
- Port to Gradle 4.4.1

* Wed Dec 12 2018 daviddavid <daviddavid> 3.0.0-6.mga7
+ Revision: 1340779
- re-enable gradle support

* Wed Dec 12 2018 neoclust <neoclust> 3.0.0-5.mga7
+ Revision: 1340682
- Sync with fc29

* Mon Dec 10 2018 daviddavid <daviddavid> 3.0.0-3.mga7
+ Revision: 1340094
- rebuild against gradle 4.3.1

* Tue Dec 04 2018 guillomovitch <guillomovitch> 3.0.0-2.mga7
+ Revision: 1338372
- rebuild with gradle support

* Tue Nov 27 2018 guillomovitch <guillomovitch> 3.0.0-1.mga7
+ Revision: 1335941
- new version 3.0.0
- switch launcher script
- temporary changes for maven upgrade

* Sun Nov 18 2018 guillomovitch <guillomovitch> 2.5.0-14.mga7
+ Revision: 1331365
- sync with latest fedora xmvn 2.5.0 package

* Fri Sep 21 2018 umeabot <umeabot> 2.5.0-13.mga7
+ Revision: 1292173
- Mageia 7 Mass Rebuild

* Tue Oct 10 2017 daviddavid <daviddavid> 2.5.0-12.mga7
+ Revision: 1170768
- rebuild with current java stack

* Sun May 07 2017 neoclust <neoclust> 2.5.0-11.mga6
+ Revision: 1099545
- Sync with fedora 25
- Second rebuild of the java stack

* Fri Feb 26 2016 neoclust <neoclust> 2.5.0-7.mga6
+ Revision: 979357
- Rebuild against current java stack

* Wed Feb 24 2016 neoclust <neoclust> 2.5.0-6.mga6
+ Revision: 978239
- First rebuild of the java stack
- sync package xmvn with fedora
- Rebuild post-bootstrap
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ zezinho <zezinho>
- bring back group an release tag
- patch by neoclust to fix build
+ daviddavid <daviddavid>
- sync with fc24 (update to 2.5.0)

* Fri Dec 26 2014 pterjan <pterjan> 2.0.1-4.mga5
+ Revision: 806035
- Sync with Fedora 21

* Tue Nov 04 2014 dmorgan <dmorgan> 2.0.1-3.mga5
+ Revision: 795527
- Revert to version 2.0.1
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 pterjan <pterjan> 2.1.0-1.mga5
+ Revision: 674084
- Add missing BuildRequires
- 2.1.0
- Sync with Fedora
- small fixes

* Sun Jun 15 2014 dmorgan <dmorgan> 1.4.0-1.mga5
+ Revision: 636587
- New version

* Sun Jun 15 2014 dmorgan <dmorgan> 1.3.0-2.mga5
+ Revision: 636322
- Rebuild against fixed maven

* Sun Jun 15 2014 dmorgan <dmorgan> 1.3.0-1.mga5
+ Revision: 636306
- New version
- New version

* Tue Oct 22 2013 umeabot <umeabot> 1.1.0-2.mga4
+ Revision: 546274
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 1.1.0-1.mga4
+ Revision: 492400
- New version
- Restore support for relative symlinks
- Do not try to relativize symlink targets
- New version 1.0.2
- New version 0.5.1

* Sat Jul 13 2013 dmorgan <dmorgan> 0.5.0-6.mga4
+ Revision: 453593
- Use version 0.5.0 Back
- Skip tests
- New snapshot
- Version 0.4.0 Final

* Wed Jul 10 2013 dmorgan <dmorgan> 0.4.0-1.mga4
+ Revision: 452604
- Update to upstream snapshot of version 0.4.0

* Wed Jul 10 2013 dmorgan <dmorgan> 0.3.1-1.mga4
+ Revision: 452583
- Revert to version 0.3.x
- Try to set maven home dir
- Do not delete jar files
- Remove not wanted files
- Remove not wanted files

* Tue Jul 09 2013 dmorgan <dmorgan> 0.5.0-5.mga4
+ Revision: 452278
- New version

* Tue Feb 19 2013 dmorgan <dmorgan> 0.3.1-1.mga3
+ Revision: 399288
- imported package xmvn


* Thu Nov 29 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0.0.1-1
- Update to upstream version 0.0.1

* Wed Nov 28 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0-2
- Add jpackage scripts

* Mon Nov  5 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 0-1
- Initial packaging
